#
# spec file for package libqt5-qtquick3d
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
%define base_name libqt5
%define real_version 5.15.17
%define so_version 5.15.17
%define tar_version qtquick3d-everywhere-src-%{version}
Name:           libqt5-qtquick3d
Version:        5.15.17+kde1
Release:        1.2
Summary:        Qt 5 Quick 3D Module
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         qt5-quick3d-assimp-5.1.patch
BuildRequires:  fdupes
BuildRequires:  libQt5Core-private-headers-devel >= 5.12
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5OpenGLExtensions-devel-static
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  pkgconfig(assimp) >= 5.0.0
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5Qml) >= 5.12
BuildRequires:  pkgconfig(Qt5Quick)
%requires_ge    libQt5Widgets5
%requires_ge    libQtQuick5

%description
Qt Quick 3D is a high level 3D API for Qt Quick.
Qt Quick 3D enables anyone to introduce 3D content into their Qt Quick
applications. Rather than requiring the end user to know advanced details of
the graphicsrendering pipeline (building framegraphs and materials),
it is now possible to simply build up a 3D scene using high level primitives.

%package -n libQt5Quick3D5
Summary:        Qt5 Quick3D Library
License:        GPL-3.0-or-later
Group:          System/Libraries

%description -n libQt5Quick3D5
Qt Quick 3D is a high level 3D API for Qt Quick.
Qt Quick 3D enables anyone to introduce 3D content into their Qt Quick
applications. Rather than requiring the end user to know advanced details of
the graphicsrendering pipeline (building framegraphs and materials),
it is now possible to simply build up a 3D scene using high level primitives.

%package -n libQt5Quick3DAssetImport5
Summary:        Qt5 Quick3D Asset Importing Library
License:        GPL-3.0-or-later
Group:          System/Libraries

%description -n libQt5Quick3DAssetImport5
Qt Quick 3D Library for importing of 3D assets.

%package tools
Summary:        Qt Development Kit
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11

%description tools
Tools for working with the Qt Quick 3D module.

%package imports
Summary:        Qt Development Kit
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11
Requires:       %{name}-tools
Requires:       libQt5Quick3D5 = %{version}
Requires:       libQt5Quick3DAssetImport5 = %{version}

%description imports
QML API for Qt Quick 3D.

%package devel
Summary:        Qt Development Kit
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11
Requires:       %{name}-tools
Requires:       libQt5Quick3D5 = %{version}
Requires:       libQt5Quick3DAssetImport5 = %{version}

%description devel
You need this package if you want to compile programs with Qt Quick 3D.

%package private-headers-devel
Summary:        Headers for the unstable API of the Qt5 Quick 3D module
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11
Requires:       %{name}-devel = %{version}

%description private-headers-devel
You need this package if you want to compile programs against the unstable API
of the Qt5 Quick 3D module.

%package examples
Summary:        Qt5 Quick 3D examples
License:        BSD-3-Clause
Group:          Development/Libraries/X11

%description examples
Examples for the Qt Quick 3D module.

%prep
%autosetup -p1 -n %{tar_version}

rm -r src/3rdparty/assimp/{src,unzip}

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5 -- \
  -system-quick3d-assimp

%make_jobs

%install
%qmake5_install

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%fdupes %{buildroot}

%post -n libQt5Quick3D5 -p /sbin/ldconfig
%postun -n libQt5Quick3D5 -p /sbin/ldconfig
%post -n libQt5Quick3DAssetImport5 -p /sbin/ldconfig
%postun -n libQt5Quick3DAssetImport5 -p /sbin/ldconfig

%files -n libQt5Quick3D5
%license LICENSE.*
# Those go mostly together
%{_libqt5_libdir}/libQt5Quick3D.so.*
%{_libqt5_libdir}/libQt5Quick3DUtils.so.*
%{_libqt5_libdir}/libQt5Quick3DRender.so.*
%{_libqt5_libdir}/libQt5Quick3DRuntimeRender.so.*

%files -n libQt5Quick3DAssetImport5
%license LICENSE.*
# This needs plugins to be useful
%{_libqt5_libdir}/libQt5Quick3DAssetImport.so.*
%dir %{_libqt5_plugindir}/assetimporters/
%{_libqt5_plugindir}/assetimporters/libassimp.so
%{_libqt5_plugindir}/assetimporters/libuip.so

%files imports
%license LICENSE.*
%{_libqt5_archdatadir}/qml/QtQuick3D/

%files tools
%license LICENSE.*
%{_libqt5_bindir}/balsam
%{_libqt5_bindir}/meshdebug

%files devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtQuick3D*/%{so_version}
%{_libqt5_includedir}/QtQuick3D*/
%{_libqt5_libdir}/cmake/Qt5Quick3D*/
%{_libqt5_libdir}/libQt5Quick3D*.prl
%{_libqt5_libdir}/libQt5Quick3D*.so
%{_libqt5_libdir}/pkgconfig/Qt5Quick3D*.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_quick3d*.pri

%files private-headers-devel
%license LICENSE.*
%{_libqt5_includedir}/QtQuick3D*/%{so_version}

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Wed May 28 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.17+kde1, rebased upstream:
  * Bump version to 5.15.17
* Mon Nov 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.16+kde1, rebased upstream:
  * Bump version to 5.15.16
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde1, rebased upstream:
  * Bump version to 5.15.15
* Mon Jul 22 2024 Christophe Marin <christophe@krop.fr>
- Use system assimp unconditionally (boo#1228199)
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde1, rebased upstream:
  * Fix crash when a custom material / effect shader variable changes
  * Skip processing unknown uniforms
  * Fix progressive anti-aliasing for PrincipledMaterial
  * Bump version to 5.15.14
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde1, rebased upstream:
  * Bump version to 5.15.13
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde1, rebased upstream:
  * Fix memory leak when destroying View3D
  * Add missing command deletes
  * Add missing free
  * Bump version to 5.15.12
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde1, rebased upstream:
  * Apply texture parameters for fbo textures
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde1, rebased upstream:
  * Drive-by doc fix
  * Clear layer resources when scene gets destroyed
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde4, rebased upstream:
  * QQuick3DNode: Fix application order of local/parent rotation matrices
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde1, rebased upstream:
  * Clean dirty nodes when deleting resources
  * Assimp: Don't use multi-arg QString::arg(..)
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde1, rebased upstream:
  * Doc: Add qmltype so Quaternion functions are collected by qdoc
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde1, rebased upstream:
  * PropertyEditor: Update designer specifics
  * Doc: Fix application order of Node.eulerRotation
  * QtQuic3D AssimpImporter: use quaternion by default
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde1, rebased upstream:
  * Handle 1bpp images in texture loading
  * Handle opacityMap with NoLighting
  * Add more error checking for shader cache import
  * Make IdComboBox compatible with both Qt6 and Qt5 creator
  * Fix writing compressed shader cache data
  * Introduce some civilization to QQuick3DShaderUtilsRenderPass::m_shaders
  * Fix bounds for imported objects
  * Check if sceneBounds is finite
  * Revert "Update commercial license headers"
  * Update designer light icons
  * Update commercial license headers
  * Remove shader cache export restriction
  * Allow import/export of shader cache data
  * Disable to use the system assimp when static-build
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Wed Dec 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch from Archlinux to build with assimp 5.1:
  * qt5-quick3d-assimp-5.1.patch
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde19:
  * Fix build with system assimp
  * Only try and use valid asset import plugins
  * Designer support: Only show supported extension in Shader source field
  * Fix render mode switch crash
  * AssimpImporter : Fix the global scale value
  * Add version 7 to supported UIP version in UipParser
  * Fix crash on setting null camera to View3D
  * Avoid using the inverse() method in GLSL for SkyBox shader
  * Fix build with -no-gui configure flag
  * Fix dynamically changing a sourceItem's size
  * Fix transparency handling with QSGTexture
  * Backport a number of Texture.sourceItem related changes from Qt 6
  * Import enhanced sourceItem manual test from Qt 6
  * Remove unused and obsolete designer files
  * Change a default value of the assimpImporter
  * Allow non-integer scale properties for Texture
  * Designer: Add default shader files for CustomMaterial and Effect
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
- Drop patches, now upstream:
  * 0001-Fix-build-with-the-system-assimp.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquick3d.git/plain/dist/changes-5.15.2/?h=5.15.2
* Tue Sep 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use the system assimp package for openSUSE Tumbleweed.
- Add patch suggested by upstream to fix build:
  * 0001-Fix-build-with-the-system-assimp.patch
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquick3d.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtquick3d.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 26 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Only needs Qt 5.12 to build
- Fix private-headers-devel requires
* Thu Feb 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
